@@ -1,7 +1,7 @@
 class UnsupportedSeleniumDriverError(Exception):
     """Custom exception for unsupported Selenium driver types."""
     def __init__(self, driver_type: str):
-        message = f"Unsupported driver type '{driver_type}'. Please choose 'chrome' or 'gecko'."
+        message = f"Unsupported driver type '{driver_type}'. Please choose 'chrome' or 'firefox'."
         super().__init__(message)
         self.driver_type = driver_type
         self.message = message
